/*============================================================================
	File:		0010 - PostgreSQL - Tempdb.sql

	Summary:	This script demonstrates how POSTGRESQL
				is using TEMPDB as temporary storage for SQL operations.

	Date:		September 2023

	PostgreSQL: 14 / 15
------------------------------------------------------------------------------
	Written by Uwe Ricken, db Berater GmbH

	This script is intended only as a supplement to demos and lectures
	given by Uwe Ricken.  
  
	THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF 
	ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED 
	TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
	PARTICULAR PURPOSE.
============================================================================*/
/*
	Basically you can create temporary tables by predefining it
	or create it directly from a schema / query
*/
DROP TABLE IF EXISTS demo_table;
CREATE TEMPORARY TABLE demo_table
(
	Id			INT				NOT NULL	PRIMARY KEY,
	name		VARCHAR(256)	NOT NULL,
	InsertUser	VARCHAR(128)	NOT NULL,
	InsertDate	TIMESTAMP		NOT NULL
);

INSERT INTO demo_table
(Id, name, InsertUser, InsertDate)
SELECT	Id, name, InsertUser, InsertDate
FROM	"dbo"."Customers";

SELECT * FROM demo_table;


/*
	As an alternative you can create a temporary table by
	inserting data from a source directly!
*/
DROP TABLE IF EXISTS demo_table;
CREATE TABLE demo_table AS TABLE "dbo"."Customers" WITH NO DATA;
SELECT * FROM demo_table;

DROP TABLE IF EXISTS demo_table;
CREATE TABLE demo_table AS TABLE "dbo"."Customers";
SELECT * FROM demo_table;

DROP TABLE IF EXISTS demo_table;
CREATE TABLE demo_table AS SELECT * FROM "dbo"."Customers" WHERE Id <= 10;
SELECT * FROM demo_table;
