/*============================================================================
	File:		0010 - SQL Server - temporary objects.sql

	Summary:	This script demonstrates how Microsoft SQL Server
				is using TEMPDB as temporary storage for SQL operations.

	Date:		March 2014

	SQL Server Version: 2008 / 2012
------------------------------------------------------------------------------
	Written by Uwe Ricken, db Berater GmbH

	This script is intended only as a supplement to demos and lectures
	given by Uwe Ricken.  
  
	THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF 
	ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED 
	TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
	PARTICULAR PURPOSE.
============================================================================*/
USE master;
GO

/*
	Basically you can create temporary tables by predefining it
	or create it directly from a schema / query
*/
DROP TABLE IF EXISTS #demo_table;
CREATE TABLE #demo_table
(
	Id			INT				NOT NULL	PRIMARY KEY CLUSTERED,
	name		VARCHAR(256)	NOT NULL,
	InsertUser	NVARCHAR(128)	NOT NULL	DEFAULT (SUSER_SNAME()),
	InsertDate	DATETIME2(0)	NOT NULL	DEFAULT (GETUTCDATE())
);
GO

INSERT INTO #demo_table
(Id, name, InsertUser, InsertDate)
SELECT	Id, name, InsertUser, InsertDate
FROM	CustomerOrders.dbo.Customers;
GO

SELECT * FROM #demo_table;
GO

/*
	As an alternative you can create a temporary table by
	inserting data from a source directly!
*/
DROP TABLE IF EXISTS #demo_table;
GO

SELECT	*
INTO	#demo_table
FROM	CustomerOrders.dbo.Customers;
GO

SELECT * FROM #demo_table;
GO
