/*
	In PostgreSQL, you can update statistics for a table to help the query planner
	make more accurate decisions when generating query execution plans.
	
	The statistics include information about the distribution of data in the table,
	which is essential for query optimization.
	
	To update statistics for a table in PostgreSQL, you can use the ANALYZE command
	or the pg_stat_statements extension.
*/
ANALYZE "dbo"."CustomerOrders";

ANALYZE VERBOSE "dbo"."CustomerOrders";

/*
	The pg_stat_statements extension is a powerful tool for monitoring and optimizing
	query performance in PostgreSQL. It can also be used to update statistics for tables.
*/
/* THAT WILL NOT WORK - must be configured as shared_preload_libraries */
CREATE EXTENSION pg_stat_statements;

/* enable pg_stat_statements for tracking of query */
SELECT	pg_stat_statements_reset();

SELECT	c.name,
		date_part('month', OrderDate)	AS	Monat,
		count(*)						AS	Orders
FROM	"dbo"."Customers" AS c
		INNER JOIN "dbo"."CustomerOrders" AS co
		ON (c.id = co.customer_id)
WHERE	c.id <= 5
		AND co.orderdate >= '2019-01-01'
		AND co.orderdate < '2020-01-01'
GROUP BY
		c.name,
		date_part('month', OrderDate)
ORDER BY
		c.name,
		Monat;

SELECT	pg_stat_statements_reset();

SELECT	*
FROM	pg_stats
WHERE	schemaname = 'dbo'
		and tablename = 'Customers';